<?php

namespace FM\Service;

use FM\Factory\AppOfflineFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use FM\Service\MinhasTarefasService;
use FM\Service\FuncionariosHierarqService;
use Doctrine\ORM\EntityManager;

class AppOfflineService
{
    protected $connection;
    protected $AppOfflineFactory;
    protected $FuncionariosHierarqService;
    protected $Environment;
    protected $newCode;

    public function __construct(EntityManager $entityManager, AppOfflineFactory $AppOfflineFactory, MinhasTarefasService $MinhasTarefasService, FuncionariosHierarqService $FuncionariosHierarqService, Environment $Environment, NewCode $newCode)
    {
        $this->connection                   = $entityManager->getConnection();
        $this->AppOfflineFactory            = $AppOfflineFactory;
        $this->MinhasTarefasService         = $MinhasTarefasService;
        $this->FuncionariosHierarqService   = $FuncionariosHierarqService;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
    }
    // ======================================== FUNÇÕES DA TELA DE TAREFAS ========================================
    // ==================== FUNÇÕES RESPONSÁVEIS POR BUSCAR OS DADOS PARA SALVAR NO MIRAGE. ====================
    public function getDadosTarefaOffline()
    {
        $parametrizacoes = $this->AppOfflineFactory->getParamOffline();
        $filtro = '';
       
        if ($parametrizacoes[0]['IDTIPOCARREGAOFFLINE'] == "1") {
            $dataInicial = date('d/m/Y');
            $dataFinal = date('d/m/Y', strtotime('+'. $parametrizacoes[0]['QTDIASCARREGAOFFLINE'] + 1 .'days'));
            $filtro = " AND CA.DTHORAAGEND BETWEEN '" . $dataInicial . "' AND '" . $dataFinal . "'";
        } elseif ($parametrizacoes[0]['IDTIPOCARREGAOFFLINE'] == "2") {
            if ($parametrizacoes[0]['DTFINAL'] != null) {
                $dataInicial = $parametrizacoes[0]['DTINICAL'];
                $dataFinal = $parametrizacoes[0]['DTFINAL'];
                $filtro = " AND CA.DTHORAAGEND BETWEEN '" . $dataInicial . "' AND '" . $dataFinal . "'";
            } else {
                $dataInicial = $parametrizacoes[0]['DTINICAL'];
                $filtro = " AND CA.DTHORAAGEND >= '" . $dataInicial . "'";
            }
        } else {
            $dataInicial = date('d/m/Y');
            $dataFinal = date('d/m/Y', strtotime('+ 7 days'));
            $filtro = " AND CA.DTHORAAGEND BETWEEN '" . $dataInicial . "' AND '" . $dataFinal . "'";
        }
        
        $operadores = $this->FuncionariosHierarqService->montarHierarquiaOperadores($this->Environment->getCdOperador());
        
        return  $this->AppOfflineFactory->getDadosTarefaOffline($operadores, $filtro);
    }

    public function getEpisTarefaOffline()
    {
        return $this->AppOfflineFactory->getEpisTarefaOffline();
    }

    public function getFotosTarefasOffline()
    {
        return $this->AppOfflineFactory->getFotosTarefasOffline();
    }

    public function getItensTarefasOffline()
    {
        $operadores = $this->FuncionariosHierarqService->montarHierarquiaOperadores($this->Environment->getCdOperador());

        return $this->AppOfflineFactory->getItensTarefasOffline($operadores);
    }

    public function getParamOffline()
    {
        $cdOperador = $this->Environment->getCdOperador();
        $operadores = $this->FuncionariosHierarqService->montarHierarquiaOperadores($this->Environment->getCdOperador());
        $dados = $this->AppOfflineFactory->getParamOffline();
        array_push($dados, $operadores);
        return $dados;
    }

    public function parametrizacaoOfflineApp($params)
    {
        $this->connection->beginTransaction();
        try {
            $cdOperador = $this->Environment->getCdOperador();
            $nrOrg = $this->Environment->getNrOrg();
            $nrParam = $this->AppOfflineFactory->getNrParametrizacoes();
            
            $param = array (
                "IDHABILITAOFFLINE"    => $params['USAOFFLINE'],
                "DTINICARREGAOFFLINE"  => isset($params["DATARANGE"][0]) ? $params["DATARANGE"][0] : null,
                "DTFIMCARREGAOFFLINE"  => isset($params["DATARANGE"][1]) ? $params["DATARANGE"][1] : null,
                "CDOPERULTATU"         => $cdOperador,
                "NRORGULTATU"          => $nrOrg,
                "QTDIASCARREGAOFFLINE" => ($params["XDIAS"] != "") ? $params["XDIAS"] : null,
                "NRPARAMGERAL"         => $nrParam[0]["NRPARAMGERAL"],
                "IDTIPOCARREGAOFFLINE" => $params["TIPOCARREGAMENTO"],
            );
            
            $this->AppOfflineFactory->atualizarParametrizacao($param);
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function getOrdenacoes()
    {
        $cdOperador = $this->Environment->getCdOperador();
    
        return $this->AppOfflineFactory->getOrdenacoes(array(
            "CDOPERADOR"        => $cdOperador,
        ));
        
    }

    public function getLocalCliente()
    {
        return $this->AppOfflineFactory->getLocalCliente();
    }

    public function getParametrizacaoGeral()
    {
        return $this->AppOfflineFactory->getParametrizacaoGeral();
    }

    public function getModeloPopOffline()
    {
        return $this->AppOfflineFactory->getModeloPopOffline();
    }

    public function getCriteriosOffline()
    {
        return $this->AppOfflineFactory->getCriteriosOffline();
    }

    public function getAtividadesOffline()
    {
        return $this->AppOfflineFactory->getAtividadesOffline();
    }

    public function getCategoriasAuditoriaOffline()
    {
        return $this->AppOfflineFactory->getCategoriasAuditoriaOffline();
    }

    public function getTopicosAuditoriaOffline()
    {
        return $this->AppOfflineFactory->getTopicosAuditoriaOffline();
    }

    public function getCriteriosAuditoriaOffline()
    {
        return $this->AppOfflineFactory->getCriteriosAuditoriaOffline();
    }

    public function getAvaliacaoOffline()
    {
        return $this->AppOfflineFactory->getAvaliacaoOffline();
    }

    public function getFotosSolicitacaoOffline()
    {
        return $this->AppOfflineFactory->getFotosSolicitacaoOffline();
    }

    public function getImagensAuditoriaOffline()
    {
        return $this->AppOfflineFactory->getImagensAuditoriaOffline();
    }

    public function getFotosVistoriasOffline()
    {
        return $this->AppOfflineFactory->getFotosVistoriasOffline();
    }

    public function getFotosAprovacaoOffline()
    {
        return $this->AppOfflineFactory->getFotosAprovacaoOffline();
    }
}
