<?php

namespace FM\Service;

use FM\Factory\OrdensServicoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use FM\Service\FindService;

class OrdensServicoService
{

    protected $OrdensServicoFactory;
    protected $environment;
    protected $newCode;
    protected $connection;
    protected $FuncionariosHierarqService;
    protected $FindService;

    public function __construct(OrdensServicoFactory $OrdensServicoFactory, EntityManager $entityManager, Environment $environment, NewCode $newCode, FuncionariosHierarqService $FuncionariosHierarqService, FindService $FindService)
    {
        $this->connection                   = $entityManager->getConnection();
        $this->OrdensServicoFactory         = $OrdensServicoFactory;
        $this->environment                  = $environment;
        $this->newCode                      = $newCode;
        $this->FuncionariosHierarqService   = $FuncionariosHierarqService;
        $this->FindService                  = $FindService;
    }

    public function getOrdensServico($parametros)
    {
        $filtro = $this->montarFiltros($parametros);
        return $this->OrdensServicoFactory->getOrdensServico($filtro);
    }

    public function getImagensOrdemServ($parametros)
    {
        return $this->OrdensServicoFactory->getImagensOrdemServ($parametros);
    }

    public function finalizarOS($parametros)
    {
        try {
            $parametros["CDOPERADOR"] = $this->environment->getCdOperador();
            $this->OrdensServicoFactory->finalizarOS($parametros);

            $parametros["DSORDEMSERVHISTORICO"] = "Ordem de serviço finalizada";
            $this->insertHistoricoOS($parametros);
        } catch (\Exception $e) {
            $this->connection->rollback();
        }
    }

    public function recusarOS($parametros)
    {
        try {
            $parametros["CDOPERADOR"] = $this->environment->getCdOperador();
            $this->OrdensServicoFactory->recusarOS($parametros);

            $parametros["DSORDEMSERVHISTORICO"] = "Ordem de serviço recusada. Motivo: " . $parametros["MOTIVO"];
            $this->insertHistoricoOS($parametros);
        } catch (\Exception $e) {
            $this->connection->rollback();
        }
    }

    public function iniciarOS($parametros)
    {
        try {
            $parametros["CDOPERADOR"] = $this->environment->getCdOperador();
            $this->OrdensServicoFactory->iniciarOS($parametros);

            $parametros["DSORDEMSERVHISTORICO"] = "Ordem de serviço iniciada.";
            $this->insertHistoricoOS($parametros);
        } catch (\Exception $e) {
            $this->connection->rollback();
        }
    }

    public function pausarOS($parametros)
    {
        try {
            $parametros["CDOPERADOR"] = $this->environment->getCdOperador();
            $this->OrdensServicoFactory->pausarOS($parametros);

            $parametros["DSORDEMSERVHISTORICO"] = "Ordem de serviço pausada.";
            $this->insertHistoricoOS($parametros);
        } catch (\Exception $e) {
            $this->connection->rollback();
        }

    }

    public function getModeloPopOrdemServ($parametros)
    {
        return $this->OrdensServicoFactory->getModeloPopOrdemServ(array(
            "NRORDEMSERV"   => $parametros["NRORDEMSERV"],
        ));
    }

    public function getAnexoModeloPopOrdemServ($parametros)
    {
        return $this->OrdensServicoFactory->getAnexoModeloPopOrdemServ(array(
            "NRORDEMSERV"   => $parametros["NRORDEMSERV"],
        ));
    }

    public function getEpisOS($parametros)
    {
        return $this->OrdensServicoFactory->getEpisOS(array(
            "NRORDEMSERV"   => $parametros["NRORDEMSERV"],
        ));
    }

    public function montarFiltros($parametros)
    {
        $filtro = '';

        if (isset($parametros['NRPRIORIDADEMANUT'])) {
            $prioridade = is_array($parametros['NRPRIORIDADEMANUT']) ? $this->FindService->formatarArray($parametros['NRPRIORIDADEMANUT']) : "'" . $parametros['NRPRIORIDADEMANUT'] . "'";
            $filtro .= " AND OSE.NRPRIORIDADEMANUT IN ( " . $prioridade . ")";
        }

        if (isset($parametros['NRTIPOMANUTENCAO'])) {
            $tipoManut = is_array($parametros['NRTIPOMANUTENCAO']) ? $this->FindService->formatarArray($parametros['NRTIPOMANUTENCAO']) : "'" . $parametros['NRTIPOMANUTENCAO'] . "'";
            $filtro .= " AND OSE.NRTIPOMANUTENCAO IN ( " . $tipoManut . ")";
        }

        if (isset($parametros['NREQUIPAMENTO'])) {
            $equipamento = is_array($parametros['NREQUIPAMENTO']) ? $this->FindService->formatarArray($parametros['NREQUIPAMENTO']) : "'" . $parametros['NREQUIPAMENTO'] . "'";
            $filtro .= " AND OSE.NREQUIPAMENTO IN ( " . $equipamento . ")";
        }

        if (isset($parametros['NRCATEGORIAMANUT'])) {
            $categoriaManut = is_array($parametros['NRCATEGORIAMANUT']) ? $this->FindService->formatarArray($parametros['NRCATEGORIAMANUT']) : "'" . $parametros['NRCATEGORIAMANUT'] . "'";
            $filtro .= " AND OSE.NRCATEGORIAMANUT IN ( " . $categoriaManut . ")";
        }

        if (isset($parametros['IDSITUACAO'])) {
            $situacao = is_array($parametros['IDSITUACAO']) ? $this->FindService->formatarArray($parametros['IDSITUACAO']) : "'" . $parametros['IDSITUACAO'] . "'";
            $filtro .= " AND OSE.IDSITUACAO IN ( " . $situacao . ")";
        }

        if (isset($parametros['IDATIVO'])) {
            $filtro .= " AND OSE.IDATIVO = '" . $parametros['IDATIVO'] . "'";
        }

        if (isset($parametros['NREQUIPE'])) {
            $situacao = is_array($parametros['NREQUIPE']) ? $this->FindService->formatarArray($parametros['NREQUIPE']) : "'" . $parametros['NREQUIPE'] . "'";
            $filtro .= " AND OSE.NREQUIPE IN ( " . $situacao . ")";
        }

        if (isset($parametros['CDOPERADOR'])) {
            $situacao = is_array($parametros['CDOPERADOR']) ? $this->FindService->formatarArray($parametros['CDOPERADOR']) : "'" . $parametros['CDOPERADOR'] . "'";
            $filtro .= " AND FR.CDOPERADOR IN ( " . $situacao . ")";
        }

        if (isset($parametros['NRPROFISSIONALEXTERNO'])) {
            $situacao = is_array($parametros['NRPROFISSIONALEXTERNO']) ? $this->FindService->formatarArray($parametros['NRPROFISSIONALEXTERNO']) : "'" . $parametros['NRPROFISSIONALEXTERNO'] . "'";
            $filtro .= " AND FR.NRPROFISSIONALEXTERNO IN ( " . $situacao . ")";
        }

        return $filtro;
    }


    public function insertHistoricoOS($parametros) {
        try {
            $this->connection->beginTransaction();
            $nrorg = $this->environment->getNrorg();

            $this->OrdensServicoFactory->insertHistoricoOS(array(
                "NRORDEMSERVHISTORICO" => $this->newCode->getCodeByTableName("FCM_ORDEMSERVHISTORICO", $nrorg, 1, 10, true),
                "NRSOLICITACAOSERV"    => $parametros["NRSOLICITACAOSERV"] ?? null,
                "NRORDEMSERV"          => $parametros["NRORDEMSERV"],
                "DSORDEMSERVHISTORICO" => $parametros["DSORDEMSERVHISTORICO"],
                "NRORG"                => $nrorg,
                "CDOPERINCLUSAO"       => $this->environment->getCdOperador(),
            ));

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
        }
    }
}