/* eslint-disable */
import { Utilities } from '@/util/Utilities';
import {
    ModalService, Modal, IModal, DialogService, LoadingService,
    Select,
    IterableComponentRender,
} from '@zeedhi/common';
import {
    Router, Http, Loader, Metadata, Singleton,
    MemoryDatasource,
} from '@zeedhi/core';
import {
    TekGrid,
} from '@zeedhi/teknisa-components-common';
import { ZdButton } from '@zeedhi/vuetify';
import { QRCodeReader } from '@zeedhi/zd-qrcode-reader-common';

@Singleton
export class QrCodeController {
    private modalLeituraQRCode!: Modal;

    private modalEscolhaTelas!: Modal;

    public url: String = '';

    public testeModal!: Modal;

    public tarefasModal!: Modal;

    public dadosCard: any;

    public dadosSeguros: any = [];

    public telaVistoria = Loader.getInstance('Fm00002VistoriasController');

    public telaTarefas = Loader.getInstance('Fm00001TarefasController');

    // public decodeQrCode({ decodeString }: any) {
    //     this.url = decodeString;
    //     this.buscaOperador();
    // }

    // public buscaOperador() {
    //     LoadingService.show();
    //     Http.post('/buscaTarefasPorOperador', {
    //         ATIVO: 'S',
    //         NRLOCALCLIENTE: this.url,
    //         CDOPERADOR: window.localStorage.getItem('CDOPERADOR'),
    //     }).then((response: any) => {
    //         this.montaCard(response);
    //         Utilities.showSuccessMessage();
    //     }).catch((error: any) => {
    //         Utilities.showErrorMessage(error);
    //     }).finally(() => {
    //         LoadingService.hide();
    //     })
    // }

    public buscaTarefas() {
        LoadingService.show();
        Http.post('/buscaTarefasPorOperador', {
            ATIVO: 'S',
            NRLOCALCLIENTE: this.url,
            CDOPERADOR: window.localStorage.getItem('CDOPERADOR'),
        }).then((response: any) => {
            this.montaCard(response, 'tarefas');
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public buscaVistorias() {
        LoadingService.show();
        Http.post('/buscaTarefasPorOperador', {
            ATIVO: 'S',
            NRLOCALCLIENTE: this.url,
            CDOPERADOR: window.localStorage.getItem('CDOPERADOR'),
        }).then((response: any) => {
            this.montaCard(response, 'vistorias');
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public montaCard(response: any, tipo: 'tarefas' | 'vistorias') {
        const tarefaUrl = 'fm_00001_000_tarefas';
        const vistoriaUrl = 'fm_00002_000_tela_vistoria';
        const pai = response.data.PAI || [];
        const filho = response.data.FILHO || [];
    
        console.log(pai);
        console.log(filho);
    
        if (pai.length === 0 && filho.length === 0) {
            const texto = `Não há ${tipo === 'vistorias' ? 'vistorias' : 'tarefas'} pendentes para este local.`;
            this.mensagem(texto);
            return;
        }
    
        if (tipo === 'vistorias' && pai.length > 0) {
            Router.replace(vistoriaUrl);
            setTimeout(() => {
                this.telaVistoria.ativaExibirDetalhes();
                this.fecharModalEscolhaTelas();
                this.fecharModalLeituraQRCode();
                this.montaGridVistorias(response.data.PAI);
            }, 3000);
            return;
        }
    
        if (tipo === 'tarefas' && filho.length > 0) {
            Router.replace(tarefaUrl);
            setTimeout(() => {
                this.telaTarefas.activateClickCard();
                this.fecharModalEscolhaTelas();
                this.fecharModalLeituraQRCode();
                this.montaGrid(response.data.FILHO);
            }, 3000);
            return;
        }    

        const texto = `Não há ${tipo === 'vistorias' ? 'vistorias' : 'tarefas'} pendentes para este local.`;
        this.mensagem(texto);
    }
    
    public async abrirModalTarefas() {
        this.tarefasModal?.destroy();
            this.tarefasModal = await ModalService.createFromJson('modal_qr_code', true);
            this.tarefasModal.show();
    }

    public fecharModalTarefas() {
        this.tarefasModal.hide();
    }

    public async montaGrid(tarefas: any) {
        await this.abrirModalTarefas();
        const grid = Metadata.getInstance<TekGrid>('tek-grid-escolha-tarefas');
        tarefas.forEach((element: any) => {
            const dados: any = {
                NRCHECKLISTAGEND: element.NRCHECKLISTAGEND,
                NMCHECKLISTAGEND: element.NMCHECKLISTAGEND,
                DATAHORA: element.DATAHORA,
            };
            grid.datasource.post(dados);
        });
    
        grid.datasource.get();
    }    
    
    public redirecionar({ row }: any) {
        Router.replace('/fm_00001_000_tarefas');
        setTimeout(() => {
            this.telaTarefas.activateClickCard(row.NRCHECKLISTAGEND);
            this.fecharModalTarefas();
            LoadingService.hide();
        }, 3000);
    }

    public async abrirModalVistorias() {
        this.testeModal?.destroy();
        this.testeModal = await ModalService.createFromJson('modal_qr_code_vistoria', true);
        this.testeModal.show();
    }

    public async montaGridVistorias(tarefas: any) {
        await this.abrirModalVistorias();
        const grid = Metadata.getInstance<TekGrid>('tek-grid-escolha-tarefas-vistoria');

        tarefas.forEach((element: any) => {
            const dados: any = {
                NRGERENCIAMENTOCHK: element.NRGERENCIAMENTOCHK,
                DTHORAAGEND: element.DTHORAAGEND,
                NMGERENCIAMENTOCHK: element.NMGERENCIAMENTOCHK,
                NMLOCALCLIENTE: element.NMLOCALCLIENTE,
            };
            grid.datasource.post(dados);
        });
        grid.datasource.get();
    }
 
    public redirecionarVistoria({ row }: any) {
        Router.replace('fm_00002_000_tela_vistoria');
        setTimeout(() => {
            this.telaVistoria.ativaExibirDetalhes(row.NRGERENCIAMENTOCHK, row.NMLOCALCLIENTE);
            this.fecharModalVistorias();
            LoadingService.hide();
        }, 3000);
    } 

    public fecharModalVistorias() {
        if (this.testeModal) {
            this.testeModal.hide();
        }
    }

    public async abrirModalLeituraQRCode() {
        this.modalLeituraQRCode?.destroy();
        this.modalLeituraQRCode = await ModalService.createFromJson('leitura_qr_code', true);
        this.modalLeituraQRCode.show();
    }

    public fecharModalLeituraQRCode() {
        this.modalLeituraQRCode?.destroy();
        this.modalLeituraQRCode.hide();
    }

    public codigoDetectado({ codes }: any) {
        const txtUrl = typeof codes === 'string' ? codes : codes?.join('');
        this.url = txtUrl.split('=')[1];
        this.abrirModalEscolhaTelas();
    }

    public async abrirModalEscolhaTelas() {
        // Controle a visibilidade dos botões antes de abrir o modal
        this.modalEscolhaTelas?.destroy();
        this.modalEscolhaTelas = await ModalService.createFromJson('modal_qrcode_escolha_telas', true);
        this.modalEscolhaTelas.show();
    }    

    public fecharModalEscolhaTelas() {
        this.modalEscolhaTelas?.destroy();
        this.modalEscolhaTelas.hide();
    }

    public ativaFecharModalEscolha() {
        const leitorQRCode = Metadata.getInstance<QRCodeReader>('leitor-qrcode');
        leitorQRCode.clearDetection();
        this.fecharModalEscolhaTelas();
    }

    public redirecionaTelaSolicitacao() {
        this.fecharModalEscolhaTelas();
        this.fecharModalLeituraQRCode();
        Router.replace('fm_00020_000_solicitacoes');
        setTimeout(() => {
            const iterable = Metadata.getInstance<IterableComponentRender>('iterable-cards-solicitacoes');

            iterable.datasource.setFilter({
                NRLOCALCLIENTE: [Number(this.url)],
                TIPO: 2
            });
        }, 2000);
    }

    public mensagem(texto: string) {
        DialogService.show({
            name: 'basic-dialog',
            title: 'Atenção',
            text: `${texto}`,
            buttons: [
                {
                    name: 'yes',
                    component: 'ZdButton',
                    label: 'Sair',
                    events: {
                        click: '{{QrCodeController.sairDialogo}}',
                    },
                },
            ],
        });
    }

    public sairDialogo() {
        DialogService.hide();
        this.fecharModalEscolhaTelas();
        this.fecharModalLeituraQRCode();
    }
}
