import { Network } from '@capacitor/network';

export interface RequestLog {
    method: 'post';
    route: string;
    data: any;
    timestamp: number;
}

export class RequestLogger {
    /**
     * Log a request if the network is offline.
     * @param route - The API route of the request
     * @param data - The request payload
     * @param method - The HTTP method (currently only 'post' is supported)
     */
    public static async logRequest(route: string, data: any, method: 'post') {
        const timestamp = Date.now();
        const log: RequestLog = {
            method,
            route,
            data,
            timestamp,
        };

        try {
            const { connected } = await Network.getStatus();

            if (!connected) {
                const offlineLogs = JSON.parse(localStorage.getItem('fmapp-log') || '[]');
                offlineLogs.push(log);
                localStorage.setItem('fmapp-log', JSON.stringify(offlineLogs));
            }
        } catch (error) {
            console.warn('Error checking network status:', error);
        }
    }
}
