import { Http, IRequestConfig } from '@zeedhi/core';

const routeHandlers: { [key: string]: (data: any, config?: IRequestConfig) => Promise<any> } = {
    '/finalizarTarefa': async (data: any) => {
        const uniqueKey = 'NRCHECKLISTAGEND';

        if (Array.isArray(data)) {
            data.forEach((row) => {
                row.IDSITUACAOAGEND = 4;
            });
        } else {
            data.IDSITUACAOAGEND = 4;
        }

        if (!Array.isArray(data)) {
            return Http.put(`minhasTarefas/${data[uniqueKey]}`, data);
        }

        const promises = data.map(async (row) => Http.put(`minhasTarefas/${row[uniqueKey]}`, row));
        return Promise.all(promises);
    },
    '/alterarStatusItem': async (data: any) => {
        const promises: Promise<any>[] = [];

        data.NMARCADOS.forEach((element: any) => {
            const dados = {
                NRTAREFAAGEND: element,
                IDREALIZADO: 'N',
            };
            const promise = Http.put(`itensTarefas/${element}`, dados);
            promises.push(promise);
        });

        data.MARCADOS.forEach((element: any) => {
            const dados = {
                NRTAREFAAGEND: element,
                IDREALIZADO: 'S',
            };
            const promise = Http.put(`itensTarefas/${element}`, dados);
            promises.push(promise);
        });

        return Promise.all(promises);
    },
    '/getTarefasCalendario': async (data: any) => {
        const tarefas = await Http.get('minhasTarefas');
        const {
        PERIODOINICIAL,
        PERIODOFINAL,
        NRLOCALCLIENTE,
        NRLOCALCLIENTEPAI,
        NRTIPOLOCALCLI,
        NREQUIPE,
        CDOPERADOR,
        CDCLIENTE,
        } = data;

        const startDate = new Date(PERIODOINICIAL);
        const endDate = new Date(PERIODOFINAL);

        const response = tarefas.data.data.filter((item: any) => {
        const taskDate = new Date(
            `${item.DTAGEND.split('/').reverse().join('-')}T${item.HORAAGEND}:00`,
        );

            return (
                taskDate >= startDate
                && taskDate <= endDate
                && (NRLOCALCLIENTE === null || item.NRLOCALCLIENTE === NRLOCALCLIENTE)
                && (NRLOCALCLIENTEPAI === null || item.LOCALPAI === NRLOCALCLIENTEPAI)
                && (NRTIPOLOCALCLI === null || item.NMCHECKLIST === NRTIPOLOCALCLI)
                && (NREQUIPE === null || item.NRSOLICITACAO === NREQUIPE)
                && (CDOPERADOR === null || item.CDOPERADOR === CDOPERADOR)
                && (CDCLIENTE === null || item.CDCLIENTE === CDCLIENTE)
            );
        });

        return { data: { data: response } };
    },
    '/verificarAlteracoes': async (data: any) => {
        const auditoria = await Http.get(`auditorias/${data.ALTERACOES.NRAUDITORIA}`);

        if (auditoria.data.data.NRRELACCATTOPIC === data.ALTERACOES.NRRELACCATTOPIC) {
            return false;
        }

        if (auditoria.data.data.DSOBSERVACAO === data.ALTERACOES.DSOBSERVACAO) {
            return false;
        }

        return true;
    },
    '/salvarCriterios': async (data: any) => {
        const promises: Promise<any>[] = [];

        data.CRITERIOSDATA.forEach((element: any) => {
            const dados = {
                IDMARCADO: 'N',
            };
            const promise = Http.put(`criterios/${element.NRCRITERIOTARGERCHK}`, dados);
            promises.push(promise);
        });

        data.CRITERIOS.forEach((element: any) => {
            const dados = {
                IDMARCADO: 'S',
            };
            const promise = Http.put(`criterios/${element}`, dados);
            promises.push(promise);
        });

        const promise = Http.put(`vistorias/${data.NRGERENCIAMENTOCHK}`, { SITUACAO: 'Em Andamento' });
        promises.push(promise);

        return Promise.all(promises);
    },
    '/finalizarVistoria': async (data: any) => {
        const dados = {
            OBS: data.DSOBSTAREFAGERCHK,
            IDSITUACAOGERCHK: '3',
            SITUACAO: 'Avaliado',
        };
        return Http.put(`vistorias/${data.NRGERENCIAMENTOCHK}`, dados);
    },
    '/alterarStatusCriterio': async (data: any) => {
        const promises: Promise<any>[] = [];
        data.criteriosN.forEach((element: any) => {
            const promise = Http.put(`criteriosAuditoria/${element}`, { IDREALIZADO: 'N' });
            promises.push(promise);
        });
        data.criteriosS.forEach((element: any) => {
            const promise = Http.put(`criteriosAuditoria/${element}`, { IDREALIZADO: 'S' });
            promises.push(promise);
        });
        return Promise.all(promises);
    },
    '/inicarOuFinalizarAuditoria': async (data: any) => Http.put(`auditorias/${data.NRAUDITORIA}`, { IDSITUACAOAUDIT: data.IDSITUACAOAUDIT }),
    '/verficarAlteracoes': async (data: any) => Http.get(`auditorias/${data.ALTERACOES.NRAUDITORIA}`),
    '/salvarDadosObservacao': async (data: any) => {
        const promises: Promise<any>[] = [];

        data.forEach((element: any) => {
            const promise = Http.put(`topicosAuditoria/${element.ID}`, { DSOBSERVACAO: element.DSOBSERVACAO });
            promises.push(promise);
        });

        return Promise.all(promises);
    },
    '/excluirImagemAuditoria': async (data: any) => Http.delete(`imagensAuditoria/${data.IMG.NRFOTORESULTAUDIT}`),
    '/getFotosTarefas': async (data: any) => {
        const fotos = await Http.get('imagensTarefas');
        const filtrado = fotos.data.data.filter((item: any) => item.NRCHECKLISTAGEND === data.NRCHECKLISTAGEND);

        return { data: { data: filtrado } };
    },
    '/getFotosSolicitacao': async (data: any) => {
        const fotos = await Http.get('fotosSolicitacao');
        const filtrado = fotos.data.data.filter((item: any) => item.NRSOLICITACAO === data.NRSOLICITACAO);

        return { data: { data: filtrado } };
    },
};

export default routeHandlers;
