import { IExternalColumn, IRouteConfig } from '@zeedhi/zeedhi-miragejs';
import config from '../../config/config';

const apiUrl = config.endPoint!; // Rota do backend da aplicação

// Resources IndexDB
// Este arquivo define "tabelas" no IndexDB que armazenarão dados a serem utilizados
// quando a aplicação estiver Offline.

export const OthersResources: Record<string, IRouteConfig<IExternalColumn>> = {
    ordenacao: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getOrdenacoes`,
        dataColumn: 'data',
        uniqueKey: 'NRORDENCAOAPP',
        columns: {
            NRORDENCAOAPP: {},
            NMTELA: {},
            NMCAMPO: {},
            IDSENTIDO: {},
        },
    },
    parametrizacao: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getParametrizacaoGeral`,
        dataColumn: 'data',
        uniqueKey: 'NRPARAMGERAL',
        columns: {
            NRPARAMGERAL: {},
            IDOBRIGACDLOCAT: {},
            IDUTILIZANOTAAUDIT: {},
            IDUTILIZAPERCENTUALAUDIT: {},
            IDHABILITAOFFLINE: {},
            IDUTILIZAGEOLOCAL: {},
            IDUTILIZAGEOLOCALINITAR: {},
        },
    },
};

export const FindResources: Record<string, IRouteConfig<IExternalColumn>> = {
    findLocal: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}findLocal`,
        dataColumn: 'data',
        uniqueKey: 'NRLOCALCLIENTE',
        columns: {
            NRLOCALCLIENTE: {},
            NMLOCALCLIENTE: {},
        },
    },
    findTipoLocal: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}findTipoLocal`,
        dataColumn: 'data',
        uniqueKey: 'NRLOCALCLIENTE',
        columns: {
            NRTIPOLOCALCLI: {},
            NMTIPOLOCALCLI: {},
        },
    },
    findOperadorHierarq: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}findOperadorHierarq`,
        dataColumn: 'data',
        uniqueKey: 'NRLOCALCLIENTE',
        columns: {
            CDOPERADOR: {},
            NMOPERADOR: {},
        },
    },
    findAtividades: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}findAtividades`,
        dataColumn: 'data',
        uniqueKey: 'NRLOCALCLIENTE',
        columns: {
            NRATIVIDADE: {},
            NMATIVIDADE: {},
            DSCORIDATIVIDADE: {},
        },
    },
    findContratosTarefas: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}findContratosTarefas`,
        dataColumn: 'data',
        uniqueKey: 'NRSEQCONTRATO',
        columns: {
            NRSEQCONTRATO: {},
            NRCONTRATOFCT: {},
        },
    },
    findClientesTarefas: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}findClientesTarefas`,
        dataColumn: 'data',
        uniqueKey: 'CDCLIENTE',
        columns: {
            CDCLIENTE: {},
            NMFANTCLIE: {},
        },
    },
};

export const TarefasResources: Record<string, IRouteConfig<IExternalColumn>> = {
    itensTarefas: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getItensTarefasOffline`,
        dataColumn: 'data',
        uniqueKey: 'NRTAREFAAGEND',
        columns: {
            NRTAREFAAGEND: {},
            NRCHECKLISTAGEND: {},
            CDOPERADOR: {},
            DTHORATAREFAAGEND: {},
            NRTAREFACHK: {},
            IDREALIZADO: {},
            NMTAREFA: {},
        },
    },
    minhasTarefas: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getMinhasTarefas`,
        dataColumn: 'data',
        uniqueKey: 'NRCHECKLISTAGEND',
        columns: {
            NRCHECKLISTAGEND: {},
            NRLOCALCLIENTE: {},
            NRCHECKLIST: {},
            CDOPERADOR: {},
            IDSITUACAOAGEND: {},
            NRSEQCONTRATO: {},
            CDCLIENTE: {},
            DTAGEND: {},
            HORAAGEND: {},
            NMCHECKLISTAGEND: {},
            NMLOCALCLIENTE: {},
            LOCALPAI: {},
            NMLOCALPAI: {},
            NMCHECKLIST: {},
            NMOPERADOR: {},
            NRCONTRATOFCT: {},
            NMRAZSOCCLIE: {},
            IDOBRIGAOBSERVACAO: {},
            IDTIPOMARCACAOTAREFA: {},
            DTHORAAGEND: {},
            NRSOLICITACAO: {},
            SITUACAO: {},
            DSOBSERVACAO: {},
        },
    },
    qtdTarefasAtivas: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}qtdTarefasAtivas`,
        dataColumn: 'data',
        uniqueKey: 'TAREFAATIVA',
        columns: {
            TAREFAATIVA: {},
        },
    },
    getTarefasPorOperador: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getTarefasPorOperador`,
        dataColumn: 'data',
        uniqueKey: 'NRCHECKLISTAGEND',
        columns: {
            NRCHECKLISTAGEND: {},
            NMCHECKLISTAGEND: {},
        },
    },
    tarefasListadas: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getTarefasListadas`,
        dataColumn: 'data',
        uniqueKey: 'NRCHECKLISTAGEND',
        columns: {
            NRCHECKLISTAGEND: {},
            CDOPERADOR: {},
            NRCONTRATOFCT: {},
            NMRAZSOCCLIE: {},
            NMCHECKLISTAGEND: {},
            IDSITUACAOAGEND: {},
            NMLOCALCLIENTE: {},
            DTAGEND: {},
            HORAAGEND: {},
            NMOPERADOR: {},
            SITUACAO: {},
            NMCAMPO: {},
            NMLOCALPAI: {},
            DSOBSERVACAO: {},
            NRLOCALCLIENTE: {},
            IDATIVO: {},
            CDCLIENTE: {},
        },
    },
    episTarefa: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getEpisTarefaOffline`,
        dataColumn: 'data',
        uniqueKey: 'NRRELCHKAGENDEPI',
        columns: {
            NRRELCHKAGENDEPI: {},
            NREPI: {},
            NMEPI: {},
        },
    },
    locais: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getLocalCliente`,
        dataColumn: 'data',
        uniqueKey: 'NRLOCALCLIENTE',
        columns: {
            NRLOCALCLIENTE: {},
            NMLOCALCLIENTE: {},
            CDCLIENTE: {},
            NRTIPOLOCALCLI: {},
            NRLOCALCLIENTEPAI: {},
            NRCHECKLISTPADR: {},
            NRGEOLOCALIZACAO: {},
        },
    },
    imagensTarefas: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getFotosTarefasOffline`,
        dataColumn: 'data',
        uniqueKey: 'NRFOTOTAREFAAGEND',
        columns: {
            NRFOTOTAREFAAGEND: {},
            DSFOTOTAREFAAGEND: {},
            NRCHECKLISTAGEND: {},
            NMCHECKLISTAGEND: {},
            IMAGEM: {},
        },
    },
};
export const AuditoriasResources: Record<string, IRouteConfig<IExternalColumn>> = {
    auditorias: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getAuditorias`,
        dataColumn: 'data',
        uniqueKey: 'NRAUDITORIA',
        columns: {
            NRAUDITORIA: {},
            NMAUDITORIA: {},
            NRLOCALCLIENTE: {},
            NMLOCALCLIENTE: {},
            NRMODELOAUDIT: {},
            NMMODELOAUDIT: {},
            NRSEQCONTRATO: {},
            NRCONTRATOFCT: {},
            CDOPERADOR: {},
            NMOPERADOR: {},
            DTAGEND: {},
            CDCLIENTE: {},
            IDOBRIGAOBSERVACAO: {},
            IDTIPORECORRENCIA: {},
            NMTIPOLOCALCLI: {},
            NMRAZSOCCLIE: {},
            NMFANTCLIE: {},
            IDTIPOMARCACAO: {},
            IDSITUACAOAUDIT: {},
        },
    },
    categoriasAuditoria: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getCategoriasAuditoriaOffline`,
        dataColumn: 'data',
        uniqueKey: 'ID',
        columns: {
            ID: {},
            NRRELACMODCATEG: {},
            NRMODELOAUDIT: {},
            NRCATEGORIAAUDIT: {},
            NMCATEGORIAAUDIT: {},
            NRAUDITORIA: {},
        },
    },
    topicosAuditoria: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getTopicosAuditoriaOffline`,
        dataColumn: 'data',
        uniqueKey: 'ID',
        columns: {
            ID: {},
            NRRELACCATTOPIC: {},
            NRCATEGORIAAUDIT: {},
            NRTOPICOAUDIT: {},
            NMTOPICOAUDIT: {},
            DSOBSERVACAO: {},
            NROBSRESULTAUDIT: {},
            NRAUDITORIA: {},
        },
    },
    criteriosAuditoria: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getCriteriosAuditoriaOffline`,
        dataColumn: 'data',
        uniqueKey: 'NRRELACRESULTCRIT',
        columns: {
            NRRELACRESULTCRIT: {},
            NRRESULTADOAUDIT: {},
            NRCRITERIOAUDIT: {},
            IDREALIZADO: {},
            NRTOPICOAUDIT: {},
            NMCRITERIOAUDIT: {},
            NRCATEGORIAAUDIT: {},
            NRAUDITORIA: {},
        },
    },
    imagensAuditoria: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getImagensAuditoriaOffline`,
        dataColumn: 'data',
        uniqueKey: 'NRRELACRESULTCRIT',
        columns: {
            NRFOTORESULTAUDIT: {},
            DSFOTOAUDITORIA: {},
            NMTOPICOAUDIT: {},
            NRAUDITORIA: {},
        },
    },
};
export const VistoriasResources: Record<string, IRouteConfig<IExternalColumn>> = {
    vistorias: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getVistoriasListadas`,
        dataColumn: 'data',
        uniqueKey: 'NRGERENCIAMENTOCHK',
        columns: {
            NRGERENCIAMENTOCHK: {},
            NMGERENCIAMENTOCHK: {},
            NRLOCALCLIENTE: {},
            CDOPERADOR: {},
            IDSITUACAOGERCHK: {},
            NRSEQCONTRATO: {},
            NRCONTRATOFCT: {},
            NMFANTCLIE: {},
            DTAGEND: {},
            HORAAGEND: {},
            NMOPERADOR: {},
            NMLOCALCLIENTE: {},
            LOCALPAI: {},
            NMLOCALPAI: {},
            IDSITUACAOAGEND: {},
            SUPERVISOR: {},
            NMCHECKLISTAGEND: {},
            OBS: {},
            DATACOMPLETA: {},
            SITUACAO: {},
            CDCLIENTE: {},
        },
    },
    modelosPOP: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getModeloPopOffline`,
        dataColumn: 'data',
        uniqueKey: 'NRRELCHKAGENDMODPOP',
        columns: {
            NRRELCHKAGENDMODPOP: {},
            NRMODELOPOP: {},
            NMMODELOPOP: {},
            DSOBSERVACAO: {},
            DESCMODELOPOP: {},
            LINKMODELOPOP: {},
            DSCAMINHOARQ: {},
            NRANEXOMODELOPOP: {},
        },
    },
    criterios: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getCriteriosOffline`,
        dataColumn: 'data',
        uniqueKey: 'NRCRITERIOTARGERCHK',
        columns: {
            NRCRITERIOTARGERCHK: {},
            NMCRITERIOTARGERCHK: {},
            NRATIVIDADECHK: {},
            NRGERENCIAMENTOCHK: {},
            IDMARCADO: {},
        },
    },
    atividades: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getAtividadesOffline`,
        dataColumn: 'data',
        uniqueKey: 'NRGERENCIAMENTOCHK',
        columns: {
            NRATIVIDADECHK: {},
            NMATIVIDADE: {},
            NRGERENCIAMENTOCHK: {},
        },
    },
    aprovacoes: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getAprovacoes`,
        dataColumn: 'data',
        uniqueKey: 'NRCHECKLISTAGEND',
        columns: {
            NRCHECKLISTAGEND: {},
            NRGERENCIAMENTOCHK: {},
            NMGERENCIAMENTOCHK: {},
            NMCHECKLISTAGEND: {},
            NRSEQCONTRATO: {},
            NRLOCALCLIENTE: {},
            NMLOCALCLIENTE: {},
            CDCLIENTE: {},
            NMRAZSOCCLIE: {},
            DTHORAAGEND: {},
            DSJUSTCANCELAMENTO: {},
            OPERRESPONSAVEL: {},
            NMOPERRESPONSAVEL: {},
            CDOPERADOR: {},
            NMOPERADOR: {},
            DTAGEND: {},
            HORAAGEND: {},
        },
    },
    fotosVistoria: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getFotosVistoriasOffline`,
        dataColumn: 'data',
        uniqueKey: 'NRFOTOTAREFAGERCHK',
        columns: {
            NRFOTOTAREFAGERCHK: {},
            DSFOTOTAREFAGERCHK: {},
            NRGERENCIAMENTOCHK: {},
            NMGERENCIAMENTOCHK: {},
        },
    },
    fotosAprovacao: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getFotosAprovacaoOffline`,
        dataColumn: 'data',
        uniqueKey: 'NRFOTOTAREFAGERCHK',
        columns: {
            NRFOTOTAREFAGERCHK: {},
            DSFOTOTAREFAGERCHK: {},
            NRGERENCIAMENTOCHK: {},
            NMGERENCIAMENTOCHK: {},
        },
    },
};
export const NaoConformidadesResources: Record<string, IRouteConfig<IExternalColumn>> = {
    naoConformidadesGerais: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getNaoConformidadesGerais`,
        dataColumn: 'data',
        uniqueKey: 'NRCRITERIOTAREFACHK',
        columns: {
            NRCRITERIOTAREFACHK: {},
            DSCRITERIOTAREFA: {},
            NRLOCALCLIENTE: {},
            NMLOCALCLIENTE: {},
            NRTIPOLOCALCLI: {},
            NMTIPOLOCALCLI: {},
            CDOPERADOR: {},
            NMOPERADOR: {},
            CDOPERADORPAI: {},
            NMOPERADORPAI: {},
            QTD: {},
        },
    },
    principaisNaoConformidades: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getPrincipaisNaoConformidades`,
        dataColumn: 'data',
        uniqueKey: 'NRAUDITORIA',
        columns: {
            NRCRITERIOTAREFACHK: {},
            NMCRITERIOTARGERCHK: {},
            QTDADE: {},
        },
    },
};
export const SolicitacaoServResources: Record<string, IRouteConfig<IExternalColumn>> = {
    categoriaManut: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}CategoriaManut`,
        dataColumn: 'data',
        uniqueKey: 'NRCATEGORIAMANUT',
        columns: {
            NRCATEGORIAMANUT: {},
            NMABREVCATEGMANUT: {},
            NMCATEGORIAMANUT: {},
            NRFUNCIONARIO: {},
        },
    },
    equipamentos: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getEquipamento`,
        dataColumn: 'data',
        uniqueKey: 'NREQUIPAMENTO',
        columns: {
            NREQUIPAMENTO: {},
            NMEQUIPAMENTO: {},
        },
    },
    impactos: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getImpactoManutencao`,
        dataColumn: 'data',
        uniqueKey: 'NRIMPACTOMANUT',
        columns: {
            NRIMPACTOMANUT: {},
            NMIMPACTOMANUT: {},
        },
    },
    perfilAcesso: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}FuncionariosPerfilAcesso`,
        dataColumn: 'data',
        uniqueKey: 'NRFUNCIONARIO',
        columns: {
            NMFUNCIONARIO: {},
            NRFUNCIONARIO: {},
            IDPERMISSSUSUARIO: {},
            IDPERMISSSTAREFAS: {},
            IDPERMISSSLOCAIS: {},
            IDPERMISSSCHECKLIST: {},
            IDPERMISSSRELATORIOS: {},
            IDPERMISSSGRAFICOS: {},
            IDPERMISSSVISTORIA: {},
            IDPERMISSSCALEND: {},
        },
    },
    solicitacoesConvertidas: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}SolicitacoesConvertidas`,
        dataColumn: 'data',
        uniqueKey: 'NRSOLICITACAOSERV',
        columns: {
            NRSOLICITACAOSERV: {},
            NRRELSOLICITAORDEMSERV: {},
            NRORDEMSERV: {},
            DTSOLICITACAOSERV: {},
            NMCATEGORIAMANUT: {},
            IDSITUACAO: {},
        },
    },
    ordensPendente: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}OrdensPendente`,
        dataColumn: 'data',
        uniqueKey: 'NRORDEMSERV',
        columns: {
            NRRELSOLICITAORDEMSERV: {},
            NRSOLICITACAOSERV: {},
            NRORDEMSERV: {},
            DTORDEMSERV: {},
            NMCATEGORIAMANUT: {},
            IDSITUACAO: {},
            IDSITUACAOORDEM: {},
        },
    },
};
export const SolicitacoesResources: Record<string, IRouteConfig<IExternalColumn>> = {
    solicitacoes: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getSolicitacoes`,
        dataColumn: 'data',
        uniqueKey: 'NRSOLICITACAO',
        columns: {
            NRSOLICITACAO: {},
            NMSOLICITACAO: {},
            DSSOLICITACAO: {},
            NRLOCALCLIENTE: {},
            NMLOCALCLIENTE: {},
            DTSOLICITACAO: {},
            DTAGEND: {},
            HORAAGEND: {},
            LOCALPAI: {},
            NMLOCALPAI: {},
            IDSITUACAO: {},
        },
    },
    avaliacoes: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getAvaliacaoOffline`,
        dataColumn: 'data',
        uniqueKey: 'ID',
        columns: {
            ID: {},
            IDSATISFACAOSOLICITA: {},
            NRSOLICITACAO: {},
        },
    },
    fotosSolicitacao: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}getFotosSolicitacaoOffline`,
        dataColumn: 'data',
        uniqueKey: 'NRIMGSOLICITACAO',
        columns: {
            NRIMGSOLICITACAO: {},
            DSCAMINHO: {},
            NRSOLICITACAO: {},
        },
    },
};
export const DashboardResources: Record<string, IRouteConfig<IExternalColumn>> = {
    tarefasFinalizadas: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}tarefasFinalizadas`,
        dataColumn: 'data',
        uniqueKey: 'NRCHECKLISTAGEND',
        columns: {
            NRCHECKLISTAGEND: {},
            NRLOCALCLIENTE: {},
            NRCHECKLIST: {},
            CDOPERADOR: {},
            IDSITUACAOAGEND: {},
            NMCHECKLISTAGEND: {},
            DTAGEND: {},
            HORAAGEND: {},
            NMLOCALCLIENTE: {},
            LOCALPAI: {},
            NMLOCALPAI: {},
            DTULTATU: {},
            NRGERENCIAMENTOCHK: {},
            IDSITUACAOGERCHK: {},
            NMOPERADOR: {},
        },
    },
    dataBaseChartPie: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}dataBaseChartPie`,
        dataColumn: 'data',
        uniqueKey: 'NMATIVIDADE',
        columns: {
            NMATIVIDADE: {},
            QUANTIDADE: {},
            DSCORIDATIVIDADE: {},
        },
    },
    dataBaseChartBar: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}dataBaseChartBar`,
        dataColumn: 'data',
        uniqueKey: 'NRCRITERIOTAREFACHK',
        columns: {
            NRCRITERIOTAREFACHK: {},
            NMCRITERIOTARGERCHK: {},
            QTDADE: {},
            DSCORIDATIVIDADE: {},
        },
    },
    tarefasAtrasadas: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}tarefasAtrasadas`,
        dataColumn: 'data',
        uniqueKey: 'NRCHECKLISTAGEND',
        columns: {
            NRCHECKLISTAGEND: {},
            NRLOCALCLIENTE: {},
            NRCHECKLIST: {},
            CDOPERADOR: {},
            IDSITUACAOAGEND: {},
            NMCHECKLISTAGEND: {},
            DTAGEND: {},
            HORAAGEND: {},
            NMLOCALCLIENTE: {},
            LOCALPAI: {},
            NMLOCALPAI: {},
            DTULTATU: {},
            NRGERENCIAMENTOCHK: {},
            IDSITUACAOGERCHK: {},
            NMOPERADOR: {},
        },
    },
    tarefasConcluidas: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}tarefasConcluidas`,
        dataColumn: 'data',
        uniqueKey: 'NRCHECKLISTAGEND',
        columns: {
            NRCHECKLISTAGEND: {},
            NRLOCALCLIENTE: {},
            NRCHECKLIST: {},
            CDOPERADOR: {},
            IDSITUACAOAGEND: {},
            NMCHECKLISTAGEND: {},
            DTAGEND: {},
            HORAAGEND: {},
            NMLOCALCLIENTE: {},
            LOCALPAI: {},
            NMLOCALPAI: {},
            DTULTATU: {},
            NRGERENCIAMENTOCHK: {},
            IDSITUACAOGERCHK: {},
            NMOPERADOR: {},
        },
    },
    ultimasTarefasRealizadas: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}ultimasTarefasRealizadas`,
        dataColumn: 'data',
        uniqueKey: 'CODIGO',
        columns: {
            CODIGO: {},
            NRLOCALCLIENTE: {},
            NRCHECKLIST: {},
            CDOPERADOR: {},
            DTAGEND: {},
            HORAAGEND: {},
            NOME: {},
            SITUACAO: {},
            TIPO: {},
            NMOPERADOR: {},
            NMLOCALCLIENTE: {},
            LOCALPAI: {},
            NMLOCALPAI: {},
        },
    },
    ordensServico: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}OrdensServicosDash`,
        dataColumn: 'data',
        uniqueKey: 'NRORDEMSERV',
        columns: {
            NRORDEMSERV: {},
            DTORDEMSERV: {},
            NMCATEGORIAMANUT: {},
            IDSITUACAO: {},
            DTAGEND: {},
            HORAAGEND: {},
            NOME: {},
            SITUACAO: {},
            TIPO: {},
            NMOPERADOR: {},
            NMLOCALCLIENTE: {},
            LOCALPAI: {},
            NMLOCALPAI: {},
        },
    },
    solicitacoesServico: {
        externalApi: true,
        persist: true,
        apiUrl: `${apiUrl}SolicitacoesServicosDash`,
        dataColumn: 'data',
        uniqueKey: 'NRSOLICITACAOSERV',
        columns: {
            NRSOLICITACAOSERV: {},
            DTSOLICITACAOSERV: {},
            NMCATEGORIAMANUT: {},
            IDSITUACAO: {},
        },
    },
};
