import { Network } from '@capacitor/network';
import { makeServer } from '@zeedhi/zeedhi-miragejs';
import {
 Http, Interceptor,
 JsonCacheService,
} from '@zeedhi/core';
import { Utilities } from '@/util/Utilities';
import adapter from '@zeedhi/axios-mirage-adapter';
import { FiltroUtil } from '@/controllers/filtroUtil';
import { useMirage } from './use-mirage';
import { RequestLog } from '../http-crud-translator/request-logger';
import config from './config';
import { OthersResources } from './config/Resources';

const metadataToCache = [
    { path: 'fm_00001_000_tarefas/fm_00001_000_tarefas' },
    { path: 'fm_00001_000_tarefas/fm_00001_001_listagem_tarefas' },
    { path: 'fm_00001_000_tarefas/fm_00001_000_detalhamento_tarefa' },
    { path: 'fm_00001_000_tarefas/fm_00001_000_reportar_tarefa' },
    { path: 'fm_00001_000_tarefas/modal/fm_00001_001_dados_tarefa' },
    { path: 'fm_00001_000_tarefas/modal/fm_00001_001_visualizar_imagens' },
    { path: 'fm_00001_000_tarefas/modal/fm_00001_000_filtrar_minhas_tarefas' },
    { path: 'fm_00001_000_tarefas/modal/fm_00001_000_anexar_imagens' },
    { path: 'fm_00040_000_auditoria/fm_00040_000_auditoria' },
    { path: 'fm_00002_000_vistoria/fm_00002_000_detalhes_vistoria' },
    { path: 'fm_00000_000_calendario/fm_00000_000_calendario' },
    { path: 'fm_00021_000_apontamento/fm_00021_001_registrar_falta' },
    { path: 'fm_00002_000_vistoria/fm_00002_000_vistoria' },
    { path: 'fm_00002_000_vistoria/modal/fm_00002_000_dados_vistoria' },
    { path: 'fm_00002_000_vistoria/modal/fm_00002_000_anexar_imagens' },
    { path: 'fm_00002_000_vistoria/modal/fm_00002_000_dados_aprovacao' },
    { path: 'fm_00002_000_vistoria/modal/fm_00002_000_filtrar_aprovacoes' },
    { path: 'fm_00002_000_vistoria/modal/fm_00002_000_filtrar_vistorias' },
    { path: 'fm_00002_000_vistoria/modal/fm_00002_000_imagens_aprovacao' },
    { path: 'fm_00002_000_vistoria/modal/fm_00002_000_recusar_report' },
    { path: 'fm_00002_000_vistoria/modal/fm_00002_000_visualizar_imagens' },
    { path: 'fm_00002_000_vistoria/fm_00002_000_aprovacoes' },
    { path: 'fm_00011_000_analise_nao_conformidade/modal/fm_00011_001_filtros_gerais' },
    { path: 'fm_00011_000_analise_nao_conformidade/modal/fm_00011_002_filtros_principais' },
    { path: 'fm_00011_000_analise_nao_conformidade/fm_00011_002_principais' },
    { path: 'fm_00011_000_analise_nao_conformidade/fm_00011_001_gerais' },
    { path: 'fm_00011_000_analise_nao_conformidade/fm_00011_000_analise_nao_conformidade' },
    { path: 'fm_00040_000_auditoria/fm_00040_001_execucao_auditoria' },
    { path: 'fm_00040_000_auditoria/modal/fm_00040_000_anexar_imagens' },
    { path: 'fm_00040_000_auditoria/modal/fm_00040_000_dados_auditoria' },
    { path: 'fm_00040_000_auditoria/modal/fm_00040_000_filtrar_auditorias' },
    { path: 'fm_00040_000_auditoria/modal/fm_00040_000_visualizar_imagens' },
    { path: 'fmt_solicitacao_servico/fmt_nova_solicitacao_servico' },
    { path: 'fm_00020_000_solicitacoes/fm_00020_000_solicitacoes' },
    { path: 'fm_00020_000_solicitacoes/fm_00020_001_criar_solicitacoes' },
    { path: 'fm_00020_000_solicitacoes/fm_00020_002_exibir_solicitacao' },
    { path: 'fm_00020_000_solicitacoes/fm_00020_003_avaliar_solicitacao' },
    { path: 'fm_00020_000_solicitacoes/modal/fm_00020_001_filtrar_solicitacoes' },
    { path: 'fm_00000_000_dashboard/fm_00000_000_dashboard' },
    { path: 'fm_00000_000_dashboard/fm_00000_001_operacional' },
    { path: 'fm_00000_000_dashboard/fm_00000_002_supervisor' },
    { path: 'fmt_dashboard/fmt_dashboard' },
    { path: 'fmt_notificacoes/fmt_notificacoes' },
    { path: 'fm_00000_000_calendario/fm_00000_000_calendario' },
    { path: 'fm_00000_000_calendario/modal/fm_00000_000_filtrar' },
    { path: 'fm_00002_000_vistoria/fm_00002_000_tela_vistoria' },
];

Interceptor.addRequestSuccess((axiosConfig) => ({ ...axiosConfig, adapter }));

const endpoint = process.env.VUE_APP_MIRAGE_END_POINT;
makeServer({ endpoint, config });

async function monitorarRede() {
    const status = await Network.getStatus();

    useMirage(!status.connected);

    Network.addListener('networkStatusChange', async (network) => {
        if (network.connected) {
            useMirage(false);

            const item = localStorage.getItem('fmapp-log') || '[]';
            const logs = JSON.parse(item);

            logs.forEach(({ method, data, route }: RequestLog) => {
                if (method === 'post') {
                    Http.post(route, data).then().catch((error) => {
                        Utilities.showErrorMessage(error);
                    });
                }
            });

            localStorage.removeItem('fmapp-log');

            JsonCacheService.clearJSONCache(metadataToCache);
            FiltroUtil.reloadResources(OthersResources);
        } else {
            useMirage(true);
        }
    });
}

monitorarRede();

JsonCacheService.saveJSONCache(metadataToCache);
